{% extends "base.html" %}

{% block styles %}
{{ super() }}
<link rel="stylesheet" type="text/css" href="{{ 'css/style.css' | url }}" />
{% endblock %}

{% block content %}
  <h1>404 - Not found</h1>
  <p>SWAN has many feathers, but not this one...</p>
{% endblock %}